@@ -7,25 +7,25 @@
 #' @param taxa quoted tsn number (taxonomic serial number)
 #' @param format output format, isubmit (you can paste in to the Phylomatic
 #'     website), or 'rsubmit' to use in fxn phylomatic_tree
-#' @param db One of "ncbi", "itis", or "apg". if you use "apg", no HTTP 
-#' requests are made (no internet connection needed), whereas if you use 
-#' "ncbi" or "itis" you do need an internet connection. IMPORTANT: 
+#' @param db One of "ncbi", "itis", or "apg". if you use "apg", no HTTP
+#' requests are made (no internet connection needed), whereas if you use
+#' "ncbi" or "itis" you do need an internet connection. IMPORTANT:
 #' see **Authentication** below if using "ncbi".
 #' @param ... curl options passed on to [taxize::tax_name()]
-#' @return string (e.g., "pinaceae/pinus/pinus_contorta"), in Phylomatic 
+#' @return string (e.g., "pinaceae/pinus/pinus_contorta"), in Phylomatic
 #' submission format
 #' @section Authentication:
 #' NCBI Entrez doesn't require that you use an API key, but you get
-#' higher rate limit with a key, from 3 to 10 requests per second, so do 
-#' get one. Run [taxize::use_entrez()] or see 
+#' higher rate limit with a key, from 3 to 10 requests per second, so do
+#' get one. Run `taxize::use_entrez()` or see
 #' https://ncbiinsights.ncbi.nlm.nih.gov/2017/11/02/new-api-keys-for-the-e-utilities/
 #' for instructions.
-#' 
-#' NCBI API key handling logic is done inside of the `taxize` package, used 
+#'
+#' NCBI API key handling logic is done inside of the `taxize` package, used
 #' inside this function.
-#' 
-#' Save your API key with the name `ENTREZ_KEY` as an R option in your 
-#' `.Rprofile` file, or as environment variables in either your `.Renviron` 
+#'
+#' Save your API key with the name `ENTREZ_KEY` as an R option in your
+#' `.Rprofile` file, or as environment variables in either your `.Renviron`
 #' file or `.bash_profile` file, or `.zshrc` file (if you use oh-my-zsh) or
 #' similar. See [Startup] for help on R options and environment
 #' variables. You cannot pass in your API key in this function.
@@ -35,7 +35,7 @@
 #' or environment variables.
 #'
 #' We strongly recommend using environment variables over R options.
-#' 
+#'
 #' Note that if you don't have an ENTREZ_KEY set, you'll get a message
 #' about it, but only once during each function call. That is, there
 #' can be of these messages per R session, across function calls.
@@ -61,17 +61,12 @@ phylomatic_names <- function(taxa, format='isubmit', db="ncbi", ...) {
 
     if (db %in% c("ncbi", "itis")) {
       family <- ck$handle_conditions(
-        taxize::tax_name(
-          query = taxa_genus, get = "family", db = db, messages = FALSE, 
-          ...)$family)
+        taxize::tax_name(taxa_genus, get = "family", db = db,
+          messages = FALSE, ...)$family)
     } else {
       tplfamily <- tpl[ match(taxa_genus, tpl$genus), "family" ]
-      dd <- taxize::apg_families[ match(tplfamily, taxize::apg_families$this), ]
-      if (nchar(as.character(dd$that), keepNA = FALSE) == 0) {
-        family <- dd$this
-      } else {
-        family <- dd$that
-      }
+      family <- taxize::apg_families[ 
+        match(tplfamily, taxize::apg_families$accepted_name), ]$accepted_name
     }
     stringg <- c(family, strsplit(nnn, " ")[[1]])
     stringg <- tolower(as.character(stringg))
